==> haskell-data-tree-print-0.1.0.2-147-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-data-tree-print.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-tree-print
version:              0.1.0.2
visibility:           public
id:                   data-tree-print-0.1.0.2-1QFoH9BTwk9KnGSlIagBfF
key:                  data-tree-print-0.1.0.2-1QFoH9BTwk9KnGSlIagBfF
license:              BSD-3-Clause
copyright:            Copyright (C) 2016 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/data-tree-print
synopsis:             Print Data instances as a nested tree
description:
    Provides functionality similar to that of the `Show` class: Taking some
    arbitrary value and returning a String.

    * Output is not intended to be valid haskell.

    * Requires a `Data.Data.Data` instance instead of a `Text.Show` one.

    * Output, if large, is often easier to parse than `show` output
    due to the formatting as a nested tree.

    * The user can adapt the behaviour at runtime using custom layouting
    expressed via syb-style extension.

category:             Pretty Printer
abi:                  1ce51376bae2c8f98e5d13d849338a17
exposed:              True
exposed-modules:      DataTreePrint
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-tree-print-0.1.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-tree-print-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-tree-print
hs-libraries:         HSdata-tree-print-0.1.0.2-1QFoH9BTwk9KnGSlIagBfF
depends:
    base-4.16.4.0 pretty-1.1.3.6 syb-0.7.2.4-3l4i7x4UWHaFMYIEmP3T6l

haddock-interfaces:
    /usr/share/doc/haskell-data-tree-print/html/data-tree-print.haddock

haddock-html:         /usr/share/doc/haskell-data-tree-print/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-tree-print-0.1.0.2-177.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-data-tree-print.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-tree-print
version:              0.1.0.2
visibility:           public
id:                   data-tree-print-0.1.0.2-C0EaIkxCCmiLtzFY9yVDO6
key:                  data-tree-print-0.1.0.2-C0EaIkxCCmiLtzFY9yVDO6
license:              BSD-3-Clause
copyright:            Copyright (C) 2016 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/data-tree-print
synopsis:             Print Data instances as a nested tree
description:
    Provides functionality similar to that of the `Show` class: Taking some
    arbitrary value and returning a String.

    * Output is not intended to be valid haskell.

    * Requires a `Data.Data.Data` instance instead of a `Text.Show` one.

    * Output, if large, is often easier to parse than `show` output
    due to the formatting as a nested tree.

    * The user can adapt the behaviour at runtime using custom layouting
    expressed via syb-style extension.

category:             Pretty Printer
abi:                  1ef9dd574fc1f5908eba11b9a5983aa8
exposed:              True
exposed-modules:      DataTreePrint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-tree-print-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-tree-print-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-tree-print-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-tree-print
hs-libraries:         HSdata-tree-print-0.1.0.2-C0EaIkxCCmiLtzFY9yVDO6
depends:
    base-4.17.2.1 pretty-1.1.3.6 syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv

haddock-interfaces:
    /usr/share/doc/haskell-data-tree-print/html/data-tree-print.haddock

haddock-html:         /usr/share/doc/haskell-data-tree-print/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
